nueli_core library

Classes

Algorithm<T>
Data Algorithm
Bucket<T>
Config<T extends Config<T, IN, OUT>, IN extends ConfigIN<IN, OUT>, OUT extends ConfigOUT<OUT, IN>>
Config ~ Widget Configuration Class.
ConfigIN<T extends ConfigIN<T, OUT>, OUT extends ConfigOUT<OUT, T>>
ConfigOUT<T extends ConfigOUT<T, IN>, IN extends ConfigIN<IN, T>>
ConfigState<T extends Config<T, IN, OUT>, IN extends ConfigIN<IN, OUT>, OUT extends ConfigOUT<OUT, IN>>
ConfigTransition<T extends Config<T, IN, OUT>, IN extends ConfigIN<IN, OUT>, OUT extends ConfigOUT<OUT, IN>>
ConfigTween<T extends Config<T, IN, OUT>, IN extends ConfigIN<IN, OUT>, OUT extends ConfigOUT<OUT, IN>>
Decor
Decor ~ BoxDecoration configuration class.
DecorIN
DecorOUT
DecorPaint
DecorTransition
DecorTween
FilledBucket<T>
Glossary
ID
Data ID Class
Inkwell
Inkwell ~ InkWell & InkResponse
InkwellIN
InkwellOUT
InkwellTransition
InkwellTween
Layout
Layout ~ LayoutWidget configuration class.
LayoutIN
LayoutOUT
LayoutRenderObject
LayoutTransition
LayoutTween
LayoutWidget
Palette
Photo
Photo ~ Image and Icon configuration class.
PhotoIN
PhotoOUT
PhotoTransition
PhotoTween
Picture
Radii
Radii ~ BorderRadius configuration class. All commands and fields varies and are self - explanatory.
RadiiIN
RadiiOUT
RadiiTransition
RadiiTween
Ref<T>
Ref ~ Data reference
Swatch
TransformData
Tranx
Tranx ~ AnimatedWidget and Tween configuration class All commands are fixed and instantaneous.
TranxIN
TranxOUT
Txt
Txt ~ Text and TextStyle configuration class.
TxtIN
TxtOUT
TxtTransition
TxtTween
Umbra
Umbra ~ BoxShadow configuration class.
UmbraIN
UmbraOUT
UmbraTransition
UmbraTween
X3D
X3D ~ Matrix4 configuration class.
X3DIN
X3DOUT
X3DTransition
X3DTween

Mixins

Add<T extends Add<T>>
@operation Addition
AND<T extends AND<T, Operand>, Operand>
@operation AND Operation
Divide<T extends Divide<T, Operand>, Operand>
@operation Division
Multiply<T extends Multiply<T, Operand>, Operand>
@operation Multiplication
NOT<T extends NOT<T>>
@operation NOT Operation
OR<T extends OR<T, Operand>, Operand>
@operation OR Operation
Subtract<T extends Subtract<T>>
@operation Subtraction

Properties

$3D X3D
no setter
$deco Decor
no setter
$decor Decor
no setter
$icon Photo
no setter
$image Photo
no setter
$ink Inkwell
no setter
$inkwell Inkwell
no setter
$layout Layout
no setter
$photo Photo
no setter
$radii Radii
no setter
$round Radii
no setter
$shadow Umbra
no setter
$text Txt
no setter
$tranx Tranx
Tranx shortcut
no setter
$txt Txt
no setter
$umbra Umbra
no setter
$well Inkwell
no setter
algog Algorithm
Shortcut to begin an event Algorithm
no setter
no setter
glossary Glossary
no setter
palette Palette
no setter

Functions

$<T>([T? data]) Ref<T>
Ref Shortcut