Config<T extends Config<T, IN, OUT> , IN extends ConfigIN<IN, OUT> , OUT extends ConfigOUT<OUT, IN> > class
abstract
Config ~ Widget Configuration Class.
Extend this class to create your own custom configuration for widgets.
Constructors
Properties
Methods
-
axis(
Axis? axis) → T -
@fixed ~ set the
axisfor children arrangement in the resulting widget -
call(
) → OUT - subclass should override this method to define the associated ConfigOUT. of the Call this method to get an instance of the associated ConfigOUT data.
-
child(
Widget? child) → T -
@fixed ~ set the
childof the resulting widget -
children(
List< Widget> ? children) → T -
@fixed ~ set the
childrenof the resulting widget -
copy<
Type> (IN iN) → T -
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → ConfigState< T, IN, OUT> -
Creates the mutable state for this widget at a given location in the tree.
override
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve<
Type> (dynamic data, Symbol tag) → T -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
update(
IN change(IN data)) → T
Operators
-
operator *(
double operand) → T -
operator +(
T operand) → T -
operator -(
T operand) → T -
operator ==(
Object other) → bool -
The equality operator.
inherited