call method

OUT call()

subclass should override this method to define the associated ConfigOUT. of the Call this method to get an instance of the associated ConfigOUT data.

Implementation

OUT call() => (_iN.get ?? _fallback)();