ConfigOUT<T extends ConfigOUT<T, IN>, IN extends ConfigIN<IN, T>> class abstract

Implementers

Constructors

ConfigOUT(IN iN)
const

Properties

axis Axis?
no setter
child Widget
no setter
children List<Widget>
no setter
hashCode int
The hash code for this object.
no setterinherited
iN → IN
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

build(BuildContext context) Widget
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrap(List<Widget> children) Widget

Operators

operator ==(Object other) bool
The equality operator.
inherited