menu
- nueli_core package
- documentation
- nueli_core.dart
- ConfigTween<T extends Config<T, IN, OUT>, IN extends ConfigIN<IN, OUT>, OUT extends ConfigOUT<OUT, IN>> class
ConfigTween<T extends Config<T, IN, OUT>, IN extends ConfigIN<IN, OUT>, OUT extends ConfigOUT<OUT, IN>> class
ConfigTween<T extends Config<T, IN, OUT>, IN extends ConfigIN<IN, OUT>, OUT extends ConfigOUT<OUT, IN>> class
abstract
Constructors
-
ConfigTween({required T begin, required T end})
-
Properties
-
begin
↔ T?
-
The value this variable has at the beginning of the animation.
getter/setter pairinherited
-
defaultConfig
→ T
-
no setter
-
end
↔ T?
-
The value this variable has at the end of the animation.
getter/setter pairinherited
-
hashCode
→ int
-
The hash code for this object.
no setterinherited
-
runtimeType
→ Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
animate(Animation<double> parent)
→ Animation<T>
-
Returns a new Animation that is driven by the given animation but that
takes on values determined by this object.
inherited
-
chain(Animatable<double> parent)
→ Animatable<T>
-
Returns a new Animatable whose value is determined by first evaluating
the given parent and then evaluating this object at the result.
inherited
-
evaluate(Animation<double> animation)
→ T
-
The current value of this object for the given Animation.
inherited
-
lerp(double t)
→ T
-
Returns the value this variable has at the given animation clock value.
inherited
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
toString()
→ String
-
A string representation of this object.
inherited
-
transform(double t)
→ T
-
Returns the interpolated value for the current value of the given animation.
inherited