Decor class

Decor ~ BoxDecoration configuration class.

Inheritance

Constructors

Decor({Key? key})

Properties

alignCenter Decor
@from Layout ~ align to center
no setter
alignEnd Decor
@from Layout ~ align to bottom right corner
no setter
alignStart Decor
@from Layout ~ align to top left corner
no setter
expand Decor
@from Layout ~ expand size to maximum
no setter
expandHeight Decor
@from Layout ~ expand height to maximum
no setter
expandWidth Decor
@from Layout ~ expand width to maximum
no setter
hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
orientDiagonal Decor
@shortcut ~ set diagonal orientation
no setter
orientHorizontal Decor
@shortcut ~ set horizontal orientation
no setter
orientVertical Decor
@shortcut ~ set vertical orientation
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

alignment(Alignment? alignment) Decor
@from Layout ~ set alignment
axis(Axis? axis) Decor
@fixed ~ set the axis for children arrangement in the resulting widget
inherited
call() DecorOUT
subclass should override this method to define the associated ConfigOUT. of the Call this method to get an instance of the associated ConfigOUT data.
inherited
child(Widget? child) Decor
@fixed ~ set the child of the resulting widget
inherited
children(List<Widget>? children) Decor
@fixed ~ set the children of the resulting widget
inherited
clip(Clip? clip) Decor
@fixed ~ set clip behaviour
color(Color color) Decor
@varies ~ set single color
constraints(BoxConstraints? constraints) Decor
@from Layout ~ set box constraints
copy<Type>(DecorIN iN) Decor
inherited
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() ConfigState<Decor, DecorIN, DecorOUT>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
fill(List<DecorPaint>? hue) Decor
@varies ~ set fill decor paint list
height(double height) Decor
@from Layout ~ set height
heightFactor(double factor) Decor
@from Layout ~ set height scale factor
inkwell(Inkwell? inkwell) Decor
@config reference ~ set inkwell
layout(Layout? layout) Decor
@config reference ~ set layout
margin(EdgeInsets? margin) Decor
@from Layout ~ set layout
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onLongPress(dynamic onLongPress()?) Decor
@from Inkwell ~ set longPress callback
onTap(dynamic onTap()?) Decor
@from Inkwell ~ set tap callback
orient(Alignment origin, Alignment focus) Decor
@varies ~ set orientation
padding(EdgeInsets? padding) Decor
@from Layout ~ set padding
paint(Color color, double stop) Decor
@varies ~ adds color with stop
radii(Radii? radii) Decor
@config reference ~ set radii
resolve<Type>(dynamic data, Symbol tag) Decor
inherited
size(double x, [double? y]) Decor
@from Layout ~ set size
stroke(double? size, [Color? color]) Decor
@varies ~ set stroke color
style(DecorStyle? style) Decor
@varies ~ set decor style
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
umbra(Umbra? umbra) Decor
@config reference ~ set umbra
update(DecorIN change(DecorIN data)) Decor
inherited
width(double width) Decor
@from Layout ~ set width
widthFactor(double factor) Decor
@from Layout ~ set width scale factor

Operators

operator *(double operand) Decor
inherited
operator +(Decor operand) Decor
inherited
operator -(Decor operand) Decor
inherited
operator ==(Object other) bool
The equality operator.
inherited