DecorOUT class

Inheritance

Constructors

DecorOUT(DecorIN iN)
const

Properties

axis Axis?
no setterinherited
child Widget
no setterinherited
children List<Widget>
no setterinherited
clip Clip
no setter
focus Alignment
no setter
hashCode int
The hash code for this object.
no setterinherited
iN DecorIN
finalinherited
inkwell Inkwell
no setter
layout Layout
no setter
origin Alignment
no setter
paints List<DecorPaint>
no setter
radii Radii
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
stroke Color
no setter
strokeSize double
no setter
style DecorStyle
no setter
toDecoration Decoration
no setter
toGradient Gradient?
no setter
umbra Umbra
no setter

Methods

build(BuildContext context) Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrap(List<Widget> children) Widget
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited