Gallery class

Inheritance
Available extensions

Constructors

Gallery()

Properties

check Picture

Available on Gallery, provided by the LibraryGallery extension

no setter
checkFill Picture

Available on Gallery, provided by the LibraryGallery extension

no setter
favorite Picture

Available on Gallery, provided by the LibraryGallery extension

no setter
favoriteFill Picture

Available on Gallery, provided by the LibraryGallery extension

no setter
flash Picture

Available on Gallery, provided by the LibraryGallery extension

no setter
flashOff Picture

Available on Gallery, provided by the LibraryGallery extension

no setter
hashCode int
The hash code for this object.
no setterinherited
iD Symbol
no setteroverride
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

at(Symbol iD) FilledBucket<Picture>
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited