Inkwell class

Inkwell ~ InkWell & InkResponse

configuration class.

Inheritance

Constructors

Inkwell({Key? key})
Inkwell.ripple(Color color, [int alpha = 100])
@template ~ create a new ripple inkwell
factory
Inkwell.rumble(Color color, [int alpha = 100])
@template ~ create a new rumble inkwell
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

axis(Axis? axis) Inkwell
@fixed ~ set the axis for children arrangement in the resulting widget
inherited
call() InkwellOUT
subclass should override this method to define the associated ConfigOUT. of the Call this method to get an instance of the associated ConfigOUT data.
inherited
child(Widget? child) Inkwell
@fixed ~ set the child of the resulting widget
inherited
children(List<Widget>? children) Inkwell
@fixed ~ set the children of the resulting widget
inherited
copy<Type>(InkwellIN iN) Inkwell
inherited
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() ConfigState<Inkwell, InkwellIN, InkwellOUT>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
focus(Color color, [int? alpha]) Inkwell
@varies ~ set focus color
highlight(Color color, [int? alpha]) Inkwell
@varies ~ set highlight color
hover(Color color, [int? alpha]) Inkwell
@varies ~ set hover color
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
onLongPress(dynamic onLongPress()?) Inkwell
@fixed ~ set long press callback
onTap(dynamic onTap()?) Inkwell
@fixed ~ set tap callback
overlay(Color color, [int? alpha]) Inkwell
@varies ~ set overlay color
radii(Radii radii) Inkwell
@config reference ~ set radii
resolve<Type>(dynamic data, Symbol tag) Inkwell
inherited
splash(Color color, [int? alpha]) Inkwell
@varies ~ set splash color
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
type(InkwellType? type) Inkwell
@fixed ~ set Inkwell type
update(InkwellIN change(InkwellIN data)) Inkwell
inherited

Operators

operator *(double operand) Inkwell
inherited
operator +(Inkwell operand) Inkwell
inherited
operator -(Inkwell operand) Inkwell
inherited
operator ==(Object other) bool
The equality operator.
inherited

Static Properties

clear Inkwell
@template ~ create a new rumble inkwell
no setter
defA int
no setter