InkwellIN class

Inheritance

Constructors

InkwellIN()

Properties

axis Axis?
getter/setter pairinherited
children List<Widget>?
getter/setter pairinherited
focus Color?
getter/setter pair
hashCode int
The hash code for this object.
no setterinherited
highlight Color?
getter/setter pair
hover Color?
getter/setter pair
onLongPress ↔ dynamic Function()?
getter/setter pair
onTap ↔ dynamic Function()?
getter/setter pair
overlay Color?
getter/setter pair
radii Radii?
getter/setter pair
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splash Color?
getter/setter pair
type InkwellType?
getter/setter pair
typeID Symbol
finalinherited

Methods

call() InkwellOUT
override
copy(InkwellIN iN) InkwellIN
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve(dynamic data, Symbol tag) InkwellIN
override
toString() String
A string representation of this object.
inherited

Operators

operator *(double operand) InkwellIN
override
operator +(InkwellIN operand) InkwellIN
override
operator -(InkwellIN operand) InkwellIN
override
operator ==(Object other) bool
The equality operator.
inherited