InkwellOUT class

Inheritance

Constructors

InkwellOUT(InkwellIN iN)
const

Properties

axis Axis?
no setterinherited
child Widget
no setterinherited
children List<Widget>
no setterinherited
focus Color
no setter
hashCode int
The hash code for this object.
no setterinherited
highlight Color
no setter
hover Color
no setter
iN InkwellIN
finalinherited
isNotActive bool
no setter
onLongPress → dynamic Function()
no setter
onTap → dynamic Function()
no setter
overlay Color
no setter
radii Radii
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
splash Color
no setter
type InkwellType
no setter

Methods

build(BuildContext context) Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrap(List<Widget> children) Widget
override

Operators

operator ==(Object other) bool
The equality operator.
inherited