LayoutOUT class

Inheritance

Constructors

LayoutOUT(LayoutIN iN)

Properties

alignment Alignment?
no setter
axis Axis?
no setterinherited
child Widget
no setterinherited
children List<Widget>
no setterinherited
constraints BoxConstraints?
no setter
hashCode int
The hash code for this object.
no setterinherited
height double?
getter/setter pair
heightFactor double
no setter
iN LayoutIN
finalinherited
longestSide double
no setter
margin EdgeInsets
no setter
padding EdgeInsets
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
shortestSide double
no setter
width double?
getter/setter pair
widthFactor double
no setter

Methods

build(BuildContext context) Widget
inherited
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrap(List<Widget> children) Widget
override

Operators

operator ==(Object other) bool
The equality operator.
inherited