Picture class
Constructors
- Picture.asset(String? path)
-
Define a new Picture with a reference to a
local asset file.
pathis the file path of the target file. - Picture.library(IconData? data)
- Define a new Picture with a reference to an Icons or CupertinoIcons data.
- Picture.network(String? src)
-
Define a new Picture with a reference to a
URL link ie
src.
Properties
Methods
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited