Radii class

Radii ~ BorderRadius configuration class. All commands and fields varies and are self - explanatory.

Inheritance

Constructors

Radii({Key? key})
Radii.all(double value)
factory
Radii.corners(double tl, double tr, double br, double bl)
factory
Radii.horizontal(double left, double right)
factory
Radii.sides(double left, double right, double top, double bottom)
factory
Radii.vertical(double top, double bottom)
factory

Properties

hashCode int
The hash code for this object.
no setterinherited
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited

Methods

axis(Axis? axis) Radii
@fixed ~ set the axis for children arrangement in the resulting widget
inherited
bl(double x, [double? y]) Radii
blX(double value) Radii
blY(double value) Radii
bottom(double value) Radii
br(double x, [double? y]) Radii
brX(double value) Radii
brY(double value) Radii
call() RadiiOUT
subclass should override this method to define the associated ConfigOUT. of the Call this method to get an instance of the associated ConfigOUT data.
inherited
child(Widget? child) Radii
@fixed ~ set the child of the resulting widget
inherited
children(List<Widget>? children) Radii
@fixed ~ set the children of the resulting widget
inherited
copy<Type>(RadiiIN iN) Radii
inherited
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() ConfigState<Radii, RadiiIN, RadiiOUT>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
left(double value) Radii
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
resolve<Type>(dynamic data, Symbol tag) Radii
inherited
tl(double x, [double? y]) Radii
tlX(double value) Radii
tlY(double value) Radii
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
top(double value) Radii
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
tr(double x, [double? y]) Radii
trX(double value) Radii
trY(double value) Radii
update(RadiiIN change(RadiiIN data)) Radii
inherited

Operators

operator *(double operand) Radii
inherited
operator +(Radii operand) Radii
inherited
operator -(Radii operand) Radii
inherited
operator ==(Object other) bool
The equality operator.
inherited

Static Properties

r108 Radii
no setter
r16 Radii
no setter
r24 Radii
no setter
r36 Radii
no setter
r54 Radii
no setter
r8 Radii
no setter
zero Radii
no setter