RadiiOUT class

Inheritance

Constructors

RadiiOUT(RadiiIN iN)

Properties

axis Axis?
no setterinherited
blX double
no setter
blY double
no setter
brX double
no setter
brY double
no setter
child Widget
no setterinherited
children List<Widget>
no setterinherited
hashCode int
The hash code for this object.
no setterinherited
iN RadiiIN
finalinherited
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
tlX double
no setter
tlY double
no setter
toBorderRadius BorderRadius
no setter
trX double
no setter
trY double
no setter

Methods

build(BuildContext context) Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrap(List<Widget> children) Widget
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited