TranxOUT class

Inheritance
Implemented types

Constructors

TranxOUT(TranxIN iN)

Properties

animation Animation<double>?
no setter
axis Axis?
no setterinherited
child Widget
no setterinherited
children List<Widget>
no setterinherited
curve Curve
no setter
duration Duration
no setter
hashCode int
The hash code for this object.
no setterinherited
iN TranxIN
finalinherited
isAnimating bool
Whether this animation is running in either direction.
no setterinherited
isCompleted bool
Whether this animation is stopped at the end.
no setteroverride
isDismissed bool
Whether this animation is stopped at the beginning.
no setteroverride
isForwardOrCompleted bool
Whether the current aim of the animation is toward completion.
no setterinherited
reverseCurve Curve
no setter
reverseDuration Duration
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
status AnimationStatus
The current status of this animation.
no setteroverride
tween List<Tween<Object?>>
no setter
value double
The current value of the animation.
no setteroverride

Methods

addListener(VoidCallback listener) → void
Calls the listener every time the value of the animation changes.
override
addStatusListener(AnimationStatusListener listener) → void
Calls listener every time the status of the animation changes.
override
build(BuildContext context) Widget
override
drive<U>(Animatable<U> child) Animation<U>
Chains a Tween (or CurveTween) to this Animation.
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
removeListener(VoidCallback listener) → void
Stop calling the listener every time the value of the animation changes.
override
removeStatusListener(AnimationStatusListener listener) → void
Stops calling the listener every time the status of the animation changes.
override
toString() String
A string representation of this object.
inherited
toStringDetails() String
Provides a string describing the status of this object, but not including information about the object itself.
override
wrap(List<Widget> children) Widget
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited