Txt class

Txt ~ Text and TextStyle configuration class.

Inheritance

Constructors

Txt({Key? key})

Properties

alignCenter Txt
@shortcut ~ align to center
no setter
alignEnd Txt
@shortcut ~ align to center
no setter
alignStart Txt
@shortcut ~ align to center
no setter
bold Txt
@shortcut ~ set font weight to bold
no setter
hashCode int
The hash code for this object.
no setterinherited
italics Txt
@shortcut ~ set font style to italics
no setter
key Key?
Controls how one widget replaces another widget in the tree.
finalinherited
lineThrough Txt
@shortcut ~ add lineThrough to decorations
no setter
overline Txt
@shortcut ~ add overline to decorations
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
underline Txt
@shortcut ~ add underline to decorations
no setter

Methods

align(TextAlign? align) Txt
@fixed ~ set text align
axis(Axis? axis) Txt
@fixed ~ set the axis for children arrangement in the resulting widget
inherited
baseline(TextBaseline? baseline) Txt
@fixed ~ set text baseline
call() TxtOUT
subclass should override this method to define the associated ConfigOUT. of the Call this method to get an instance of the associated ConfigOUT data.
inherited
child(Widget? child) Txt
@fixed ~ set the child of the resulting widget
inherited
children(List<Widget>? children) Txt
@fixed ~ set the children of the resulting widget
inherited
color(Color color) Txt
@varies ~ set color
copy<Type>(TxtIN iN) Txt
inherited
createElement() StatefulElement
Creates a StatefulElement to manage this widget's location in the tree.
inherited
createState() ConfigState<Txt, TxtIN, TxtOUT>
Creates the mutable state for this widget at a given location in the tree.
inherited
debugDescribeChildren() List<DiagnosticsNode>
Returns a list of DiagnosticsNode objects describing this node's children.
inherited
debugFillProperties(DiagnosticPropertiesBuilder properties) → void
Add additional properties associated with the node.
inherited
decoration(TextDecoration decoration) Txt
@fixed ~ add text decoration
inkwell(Inkwell inkwell) Txt
@fixed ~ set text inkwell
inline(List<Txt> children) Txt
@fixed ~ set text span children
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
overflow(TextOverflow? overflow) Txt
@fixed ~ set text overflow
resolve<Type>(dynamic data, Symbol tag) Txt
inherited
size(double size) Txt
@varies ~ set size
style(FontStyle? style) Txt
@fixed ~ set font style
text(String? text) Txt
@fixed ~ set text
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style}) DiagnosticsNode
Returns a debug representation of the object that is used by debugging tools and by DiagnosticsNode.toStringDeep.
inherited
toString({DiagnosticLevel minLevel = DiagnosticLevel.info}) String
A string representation of this object.
inherited
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) String
Returns a string representation of this node and its descendants.
inherited
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) String
Returns a one-line detailed description of the object.
inherited
toStringShort() String
A short, textual description of this widget.
inherited
umbra(Umbra umbra) Txt
@fixed ~ set text umbra
update(TxtIN change(TxtIN data)) Txt
inherited
weight(FontWeight? weight) Txt
@fixed ~ set font weight

Operators

operator *(double operand) Txt
inherited
operator +(Txt operand) Txt
inherited
operator -(Txt operand) Txt
inherited
operator ==(Object other) bool
The equality operator.
inherited