TxtOUT class

Inheritance

Constructors

TxtOUT(TxtIN iN)

Properties

align TextAlign
no setter
axis Axis?
no setterinherited
backgroundColor Color
no setter
baseline TextBaseline?
no setter
child Widget
no setterinherited
children List<Widget>
no setterinherited
color Color
no setter
decorations List<TextDecoration>
no setter
hashCode int
The hash code for this object.
no setterinherited
iN TxtIN
finalinherited
inkwell Inkwell
no setter
maxLines int?
no setter
overflow TextOverflow
no setter
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
size double
no setter
style FontStyle
no setter
text String
no setter
toRecognizer GestureRecognizer?
no setter
toTextStyle TextStyle
no setter
umbra Umbra
no setter
weight FontWeight
no setter

Methods

build(BuildContext context) Widget
override
noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited
wrap(List<Widget> children) Widget
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited