Layout class
Layout ~ LayoutWidget configuration class.
- Inheritance
Properties
- alignCenter → Layout
-
@shortcut ~ align to center
no setter
- alignEnd → Layout
-
@shortcut ~ align to bottom right corner
no setter
- alignStart → Layout
-
@shortcut ~ align to top left corner
no setter
- expand → Layout
-
@shortcut ~ expand size to maximum
no setter
- expandHeight → Layout
-
@shortcut ~ expand height to maximum
no setter
- expandWidth → Layout
-
@shortcut ~ expand width to maximum
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- key → Key?
-
Controls how one widget replaces another widget in the tree.
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
Methods
-
alignment(
Alignment? alignment) → Layout - @varies ~ set alignment
-
axis(
Axis? axis) → Layout -
@fixed ~ set the
axisfor children arrangement in the resulting widgetinherited -
call(
) → LayoutOUT -
subclass should override this method to
define the associated ConfigOUT. of the
Call this method to get an instance of the
associated ConfigOUT data.
inherited
-
child(
Widget? child) → Layout -
@fixed ~ set the
childof the resulting widgetinherited -
children(
List< Widget> ? children) → Layout -
@fixed ~ set the
childrenof the resulting widgetinherited -
constraints(
BoxConstraints? constraints) → Layout - @varies ~ set box constraints
-
copy<
Type> (LayoutIN iN) → Layout -
inherited
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → ConfigState< Layout, LayoutIN, LayoutOUT> -
Creates the mutable state for this widget at a given location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
height(
double height) → Layout - @varies ~ set height
-
heightFactor(
double factor) → Layout - @varies ~ set height scale factor
-
margin(
EdgeInsets? margin) → Layout - @varies ~ set margin
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
padding(
EdgeInsets? padding) → Layout - @varies ~ set padding
-
resolve<
Type> (dynamic data, Symbol tag) → Layout -
inherited
-
size(
double x, [double? y]) → Layout - @varies ~ set size
-
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
update(
LayoutIN change(LayoutIN data)) → Layout -
inherited
-
width(
double width) → Layout - @varies ~ set width
-
widthFactor(
double factor) → Layout - @varies ~ set width scale factor
Operators
-
operator *(
double operand) → Layout -
inherited
-
operator +(
Layout operand) → Layout -
inherited
-
operator -(
Layout operand) → Layout -
inherited
-
operator ==(
Object other) → bool -
The equality operator.
inherited