LayoutIN class
Constructors
- LayoutIN()
Properties
- alignment ↔ Alignment?
-
getter/setter pair
- axis ↔ Axis?
-
getter/setter pairinherited
-
children
↔ List<
Widget> ? -
getter/setter pairinherited
- constraints ↔ BoxConstraints?
-
getter/setter pair
- hashCode → int
-
The hash code for this object.
no setterinherited
- height ↔ double?
-
getter/setter pair
- heightFactor ↔ double?
-
getter/setter pair
- margin ↔ EdgeInsets?
-
getter/setter pair
- padding ↔ EdgeInsets?
-
getter/setter pair
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- typeID → Symbol
-
finalinherited
- width ↔ double?
-
getter/setter pair
- widthFactor ↔ double?
-
getter/setter pair
Methods
-
call(
) → LayoutOUT -
override
-
copy(
LayoutIN iN) → LayoutIN -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
resolve(
dynamic data, Symbol tag) → LayoutIN -
override
-
toString(
) → String -
A string representation of this object.
inherited
Operators
-
operator *(
double operand) → LayoutIN -
override
-
operator +(
LayoutIN operand) → LayoutIN -
override
-
operator -(
LayoutIN operand) → LayoutIN -
override
-
operator ==(
Object other) → bool -
The equality operator.
inherited