Photo class
Photo ~ Image and Icon configuration class.
Methods
-
alignment(Alignment? alignment)
→ Photo
-
@from Layout ~ set alignment
-
axis(Axis? axis)
→ Photo
-
@fixed ~ set the
axis for children
arrangement in the resulting widget
inherited
-
blendMode(BlendMode? blendMode)
→ Photo
-
@fixed ~ set blend mode
-
boxFit(BoxFit? boxFit)
→ Photo
-
@fixed ~ set box fit
-
call()
→ PhotoOUT
-
subclass should override this method to
define the associated ConfigOUT. of the
Call this method to get an instance of the
associated ConfigOUT data.
inherited
-
child(Widget? child)
→ Photo
-
@fixed ~ set the
child of the resulting
widget
inherited
-
children(List<Widget>? children)
→ Photo
-
@fixed ~ set the
children of the
resulting widget
inherited
-
color(Color color)
→ Photo
-
@varies ~ set color filter
-
constraints(BoxConstraints? constraints)
→ Photo
-
@from Layout ~ set box constraints
-
copy<Type>(PhotoIN iN)
→ Photo
-
inherited
-
createElement()
→ StatefulElement
-
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState()
→ ConfigState<Photo, PhotoIN, PhotoOUT>
-
Creates the mutable state for this widget at a given location in the tree.
inherited
-
debugDescribeChildren()
→ List<DiagnosticsNode>
-
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(DiagnosticPropertiesBuilder properties)
→ void
-
Add additional properties associated with the node.
inherited
-
height(double height)
→ Photo
-
@from Layout ~ set height
-
heightFactor(double factor)
→ Photo
-
@from Layout ~ set height scale factor
-
inkwell(Inkwell inkwell)
→ Photo
-
@config reference ~ set inkwell
-
layout(Layout layout)
→ Photo
-
@config reference ~ set layout
-
margin(EdgeInsets? margin)
→ Photo
-
@from Layout ~ set layout
-
noSuchMethod(Invocation invocation)
→ dynamic
-
Invoked when a nonexistent method or property is accessed.
inherited
-
onLongPress(dynamic onLongPress()?)
→ Photo
-
@from Inkwell ~ set longPress callback
-
onTap(dynamic onTap()?)
→ Photo
-
@from Inkwell ~ set tap callback
-
padding(EdgeInsets? padding)
→ Photo
-
@from Layout ~ set padding
-
picture(Picture? picture)
→ Photo
-
@fixed ~ set picture data
-
resolve<Type>(dynamic data, Symbol tag)
→ Photo
-
inherited
-
size(double x, [double? y])
→ Photo
-
@from Layout ~ set size
-
toDiagnosticsNode({String? name, DiagnosticsTreeStyle? style})
→ DiagnosticsNode
-
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString({DiagnosticLevel minLevel = DiagnosticLevel.info})
→ String
-
A string representation of this object.
inherited
-
toStringDeep({String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65})
→ String
-
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow({String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug})
→ String
-
Returns a one-line detailed description of the object.
inherited
-
toStringShort()
→ String
-
A short, textual description of this widget.
inherited
-
update(PhotoIN change(PhotoIN data))
→ Photo
-
inherited
-
width(double width)
→ Photo
-
@from Layout ~ set width
-
widthFactor(double factor)
→ Photo
-
@from Layout ~ set width scale factor