PhotoOUT class
Properties
- axis → Axis?
-
no setterinherited
- blendMode → BlendMode
-
no setter
- boxFit → BoxFit
-
no setter
- child → Widget
-
no setterinherited
-
children
→ List<
Widget> -
no setterinherited
- color → Color?
-
no setter
- hashCode → int
-
The hash code for this object.
no setterinherited
- iN → PhotoIN
-
finalinherited
- inkwell → Inkwell
-
no setter
- layout → Layout
-
no setter
- picture → Picture
-
no setter
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toPhotoData → Picture
-
no setter
Methods
-
build(
BuildContext context) → Widget -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
wrap(
List< Widget> children) → Widget -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited