X3D class
X3D ~ Matrix4 configuration class.
- Inheritance
Constructors
- X3D({Key? key})
- X3D.perspective(int level)
-
factory
Properties
Methods
-
alignment(
Alignment alignment) → X3D -
axis(
Axis? axis) → X3D -
@fixed ~ set the
axisfor children arrangement in the resulting widgetinherited -
base(
Matrix4? base) → X3D -
call(
) → X3DOUT -
subclass should override this method to
define the associated ConfigOUT. of the
Call this method to get an instance of the
associated ConfigOUT data.
inherited
-
child(
Widget? child) → X3D -
@fixed ~ set the
childof the resulting widgetinherited -
children(
List< Widget> ? children) → X3D -
@fixed ~ set the
childrenof the resulting widgetinherited -
copy<
Type> (X3DIN iN) → X3D -
inherited
-
createElement(
) → StatefulElement -
Creates a StatefulElement to manage this widget's location in the tree.
inherited
-
createState(
) → ConfigState< X3D, X3DIN, X3DOUT> -
Creates the mutable state for this widget at a given location in the tree.
inherited
-
debugDescribeChildren(
) → List< DiagnosticsNode> -
Returns a list of DiagnosticsNode objects describing this node's
children.
inherited
-
debugFillProperties(
DiagnosticPropertiesBuilder properties) → void -
Add additional properties associated with the node.
inherited
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
offsetX(
double x) → X3D -
offsetY(
double y) → X3D -
offsetZ(
double z) → X3D -
panX(
double x) → X3D -
panY(
double y) → X3D -
panZ(
double z) → X3D -
resolve<
Type> (dynamic data, Symbol tag) → X3D -
inherited
-
rotate(
double rotation) → X3D -
scale(
{double x = 0, double y = 0, double z = 0}) → X3D -
scaleX(
double x) → X3D -
scaleY(
double y) → X3D -
scaleZ(
double z) → X3D -
shift(
{double x = 0, double y = 0, double z = 0}) → X3D -
skew(
{double x = 0, double y = 0, double z = 0}) → X3D -
skewX(
double x) → X3D -
skewY(
double y) → X3D -
toDiagnosticsNode(
{String? name, DiagnosticsTreeStyle? style}) → DiagnosticsNode -
Returns a debug representation of the object that is used by debugging
tools and by DiagnosticsNode.toStringDeep.
inherited
-
toString(
{DiagnosticLevel minLevel = DiagnosticLevel.info}) → String -
A string representation of this object.
inherited
-
toStringDeep(
{String prefixLineOne = '', String? prefixOtherLines, DiagnosticLevel minLevel = DiagnosticLevel.debug, int wrapWidth = 65}) → String -
Returns a string representation of this node and its descendants.
inherited
-
toStringShallow(
{String joiner = ', ', DiagnosticLevel minLevel = DiagnosticLevel.debug}) → String -
Returns a one-line detailed description of the object.
inherited
-
toStringShort(
) → String -
A short, textual description of this widget.
inherited
-
transform(
TransformData transform) → X3D -
translate(
{double x = 0, double y = 0, double z = 0}) → X3D -
update(
X3DIN change(X3DIN data)) → X3D -
inherited
-
zoom(
double zoom) → X3D
Operators
-
operator *(
double operand) → X3D -
inherited
-
operator +(
X3D operand) → X3D -
inherited
-
operator -(
X3D operand) → X3D -
inherited
-
operator ==(
Object other) → bool -
The equality operator.
inherited