X3DOUT class
Properties
- alignment → Alignment
-
no setter
- axis → Axis?
-
no setterinherited
- base → Matrix4
-
no setter
- child → Widget
-
no setterinherited
-
children
→ List<
Widget> -
no setterinherited
- hashCode → int
-
The hash code for this object.
no setterinherited
- iN → X3DIN
-
finalinherited
- runtimeType → Type
-
A representation of the runtime type of the object.
no setterinherited
- toMatrix4 → Matrix4
-
no setter
-
transforms
→ List<
TransformData> -
no setter
Methods
-
build(
BuildContext context) → Widget -
override
-
noSuchMethod(
Invocation invocation) → dynamic -
Invoked when a nonexistent method or property is accessed.
inherited
-
toString(
) → String -
A string representation of this object.
inherited
-
wrap(
List< Widget> children) → Widget -
inherited
Operators
-
operator ==(
Object other) → bool -
The equality operator.
inherited